==> huaweicloudsdkdataartsstudio-3.1.97-py2.py3-none-any.whl: huaweicloudsdkdataartsstudio/v1/model/update_design_table_quality_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateDesignTableQualityRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'workspace': 'str',
        'x_project_id': 'str',
        'table_id': 'str',
        'body': 'UpdateDesignTableQualityParam'
    }

    attribute_map = {
        'workspace': 'workspace',
        'x_project_id': 'X-Project-Id',
        'table_id': 'table_id',
        'body': 'body'
    }

    def __init__(self, workspace=None, x_project_id=None, table_id=None, body=None):
        """UpdateDesignTableQualityRequest

        The model defined in huaweicloud sdk

        :param workspace: 工作空间ID，获取方法请参见[实例ID和工作空间ID](dataartsstudio_02_0350.xml)。
        :type workspace: str
        :param x_project_id: 项目ID，获取方法请参见[项目ID和账号ID](projectid_accountid.xml)。  多project场景采用AK/SK认证的接口请求，则该字段必选。
        :type x_project_id: str
        :param table_id: 表的ID。
        :type table_id: str
        :param body: Body of the UpdateDesignTableQualityRequest
        :type body: :class:`huaweicloudsdkdataartsstudio.v1.UpdateDesignTableQualityParam`
        """
        
        

        self._workspace = None
        self._x_project_id = None
        self._table_id = None
        self._body = None
        self.discriminator = None

        self.workspace = workspace
        if x_project_id is not None:
            self.x_project_id = x_project_id
        self.table_id = table_id
        if body is not None:
            self.body = body

    @property
    def workspace(self):
        """Gets the workspace of this UpdateDesignTableQualityRequest.

        工作空间ID，获取方法请参见[实例ID和工作空间ID](dataartsstudio_02_0350.xml)。

        :return: The workspace of this UpdateDesignTableQualityRequest.
        :rtype: str
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        """Sets the workspace of this UpdateDesignTableQualityRequest.

        工作空间ID，获取方法请参见[实例ID和工作空间ID](dataartsstudio_02_0350.xml)。

        :param workspace: The workspace of this UpdateDesignTableQualityRequest.
        :type workspace: str
        """
        self._workspace = workspace

    @property
    def x_project_id(self):
        """Gets the x_project_id of this UpdateDesignTableQualityRequest.

        项目ID，获取方法请参见[项目ID和账号ID](projectid_accountid.xml)。  多project场景采用AK/SK认证的接口请求，则该字段必选。

        :return: The x_project_id of this UpdateDesignTableQualityRequest.
        :rtype: str
        """
        return self._x_project_id

    @x_project_id.setter
    def x_project_id(self, x_project_id):
        """Sets the x_project_id of this UpdateDesignTableQualityRequest.

        项目ID，获取方法请参见[项目ID和账号ID](projectid_accountid.xml)。  多project场景采用AK/SK认证的接口请求，则该字段必选。

        :param x_project_id: The x_project_id of this UpdateDesignTableQualityRequest.
        :type x_project_id: str
        """
        self._x_project_id = x_project_id

    @property
    def table_id(self):
        """Gets the table_id of this UpdateDesignTableQualityRequest.

        表的ID。

        :return: The table_id of this UpdateDesignTableQualityRequest.
        :rtype: str
        """
        return self._table_id

    @table_id.setter
    def table_id(self, table_id):
        """Sets the table_id of this UpdateDesignTableQualityRequest.

        表的ID。

        :param table_id: The table_id of this UpdateDesignTableQualityRequest.
        :type table_id: str
        """
        self._table_id = table_id

    @property
    def body(self):
        """Gets the body of this UpdateDesignTableQualityRequest.

        :return: The body of this UpdateDesignTableQualityRequest.
        :rtype: :class:`huaweicloudsdkdataartsstudio.v1.UpdateDesignTableQualityParam`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UpdateDesignTableQualityRequest.

        :param body: The body of this UpdateDesignTableQualityRequest.
        :type body: :class:`huaweicloudsdkdataartsstudio.v1.UpdateDesignTableQualityParam`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateDesignTableQualityRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdataartsstudio-3.1.119-py2.py3-none-any.whl: huaweicloudsdkdataartsstudio/v1/model/update_design_table_quality_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateDesignTableQualityRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'workspace': 'str',
        'x_project_id': 'str',
        'table_id': 'str',
        'body': 'UpdateDesignTableQualityParam'
    }

    attribute_map = {
        'workspace': 'workspace',
        'x_project_id': 'X-Project-Id',
        'table_id': 'table_id',
        'body': 'body'
    }

    def __init__(self, workspace=None, x_project_id=None, table_id=None, body=None):
        """UpdateDesignTableQualityRequest

        The model defined in huaweicloud sdk

        :param workspace: 工作空间ID，获取方法请参见[实例ID和工作空间ID](dataartsstudio_02_0350.xml)。
        :type workspace: str
        :param x_project_id: 项目ID，获取方法请参见[项目ID和账号ID](projectid_accountid.xml)。  多project场景采用AK/SK认证的接口请求，则该字段必选。
        :type x_project_id: str
        :param table_id: 表的ID，填写String类型替代Long类型。
        :type table_id: str
        :param body: Body of the UpdateDesignTableQualityRequest
        :type body: :class:`huaweicloudsdkdataartsstudio.v1.UpdateDesignTableQualityParam`
        """
        
        

        self._workspace = None
        self._x_project_id = None
        self._table_id = None
        self._body = None
        self.discriminator = None

        self.workspace = workspace
        if x_project_id is not None:
            self.x_project_id = x_project_id
        self.table_id = table_id
        if body is not None:
            self.body = body

    @property
    def workspace(self):
        """Gets the workspace of this UpdateDesignTableQualityRequest.

        工作空间ID，获取方法请参见[实例ID和工作空间ID](dataartsstudio_02_0350.xml)。

        :return: The workspace of this UpdateDesignTableQualityRequest.
        :rtype: str
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        """Sets the workspace of this UpdateDesignTableQualityRequest.

        工作空间ID，获取方法请参见[实例ID和工作空间ID](dataartsstudio_02_0350.xml)。

        :param workspace: The workspace of this UpdateDesignTableQualityRequest.
        :type workspace: str
        """
        self._workspace = workspace

    @property
    def x_project_id(self):
        """Gets the x_project_id of this UpdateDesignTableQualityRequest.

        项目ID，获取方法请参见[项目ID和账号ID](projectid_accountid.xml)。  多project场景采用AK/SK认证的接口请求，则该字段必选。

        :return: The x_project_id of this UpdateDesignTableQualityRequest.
        :rtype: str
        """
        return self._x_project_id

    @x_project_id.setter
    def x_project_id(self, x_project_id):
        """Sets the x_project_id of this UpdateDesignTableQualityRequest.

        项目ID，获取方法请参见[项目ID和账号ID](projectid_accountid.xml)。  多project场景采用AK/SK认证的接口请求，则该字段必选。

        :param x_project_id: The x_project_id of this UpdateDesignTableQualityRequest.
        :type x_project_id: str
        """
        self._x_project_id = x_project_id

    @property
    def table_id(self):
        """Gets the table_id of this UpdateDesignTableQualityRequest.

        表的ID，填写String类型替代Long类型。

        :return: The table_id of this UpdateDesignTableQualityRequest.
        :rtype: str
        """
        return self._table_id

    @table_id.setter
    def table_id(self, table_id):
        """Sets the table_id of this UpdateDesignTableQualityRequest.

        表的ID，填写String类型替代Long类型。

        :param table_id: The table_id of this UpdateDesignTableQualityRequest.
        :type table_id: str
        """
        self._table_id = table_id

    @property
    def body(self):
        """Gets the body of this UpdateDesignTableQualityRequest.

        :return: The body of this UpdateDesignTableQualityRequest.
        :rtype: :class:`huaweicloudsdkdataartsstudio.v1.UpdateDesignTableQualityParam`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UpdateDesignTableQualityRequest.

        :param body: The body of this UpdateDesignTableQualityRequest.
        :type body: :class:`huaweicloudsdkdataartsstudio.v1.UpdateDesignTableQualityParam`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateDesignTableQualityRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
